@@ -11,9 +11,9 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
-"""zope.app.preferences common test related classes/functions/objects.
+"""zope.app.preference common test related classes/functions/objects.
 
-$Id: testing.py 113358 2010-06-11 17:17:44Z icemac $
+$Id: testing.py 113484 2010-06-15 13:41:08Z icemac $
 """
 
 __docformat__ = "reStructuredText"
