@@ -13,37 +13,25 @@
 ##############################################################################
 """Tests for the Preferences System
 
-$Id: tests.py 113358 2010-06-11 17:17:44Z icemac $
+$Id: tests.py 113388 2010-06-12 11:45:38Z icemac $
 """
 from zope.app.testing import setup, functional
 from zope.component import testing
-import doctest
 import unittest
 import zope.app.preference.testing
 
 
 def setUp(test):
-    testing.setUp(test)
     setup.setUpTestAsModule(test, 'zope.app.preference.README')
 
 
-def ftest_setUp(test):
-    setup.setUpTestAsModule(test, 'zope.app.preference.zmi')
-
-
 def tearDown(test):
     testing.tearDown(test)
     setup.tearDownTestAsModule(test)
 
 
 def test_suite():
-    browser_tests = functional.FunctionalDocFileSuite(
-        'zmi.txt', setUp=ftest_setUp, tearDown=tearDown)
-    browser_tests.layer = zope.app.preference.testing.PreferencesLayer
-
-    return unittest.TestSuite((
-        doctest.DocFileSuite('README.txt',
-                             setUp=setUp, tearDown=tearDown,
-                             optionflags=doctest.NORMALIZE_WHITESPACE),
-        browser_tests,
-        ))
+    tests = functional.FunctionalDocFileSuite(
+        'README.txt', setUp=setUp, tearDown=tearDown)
+    tests.layer = zope.app.preference.testing.PreferencesLayer
+    return unittest.TestSuite((tests,))
